@@ -20,7 +20,7 @@ path_precommit_exec <- function(check_if_exists = TRUE) {
   if (!check_if_exists) {
     return(final)
   }
-  if (!fs::file_exists(final)) {
+  if (!file_exists(final)) {
     rlang::abort(paste0(
       "pre-commit executable does not exist at ",
       final,
@@ -45,31 +45,34 @@ path_pre_commit_exec <- function(check_if_exists = TRUE) {
 
 #' Derive the path to the pre-commit executable
 #'
-#' All these functions return "" if search was not successful.
+#' Returns "" if search was not successful, the path otherwise.
 #' @section Heuristic:
 #' - First check if there is an executable on the `$PATH` using
 #'   [path_derive_precommit_exec_path()]
-#' - If not, check if we can find one in a conda environment with
-#'   [path_derive_precommit_exec_conda()].
 #' - Search os dependent for other possible locations for common installation
 #'   methods.
+#' - If not, check if we can find one in a conda environment with
+#'   [path_derive_precommit_exec_conda()]. Do this last as it's the slowest.
 #' @keywords internal
 path_derive_precommit_exec <- function() {
   path <- path_derive_precommit_exec_path()
-  if (path == "") {
-    path <- path_derive_precommit_exec_conda()
+  os <- tolower(Sys.info()[["sysname"]])
+  if (os == "darwin") {
+    path <- c(path, path_derive_precommit_exec_macOS())
+  } else if (os == "windows") {
+    path <- c(path, path_derive_precommit_exec_win())
+  } else if (os == "linux") {
+    path <- c(path, path_derive_precommit_exec_linux())
   }
-  if (path == "") {
-    os <- tolower(Sys.info()[["sysname"]])
-    if (os == "darwin") {
-      path <- path_derive_precommit_exec_macOS()
-    } else if (os == "windows") {
-      path <- path_derive_precommit_exec_win()
-    } else if (os == "linux") {
-      path <- path_derive_precommit_exec_linux()
-    }
+  path <- unique(path[path != ""])
+  if (length(path) == 0) {
+    path_derive_precommit_exec_conda()
+  } else if (length(path) == 1) {
+    path
+  } else {
+    path_warn_multiple_execs(path)
+    path[1]
   }
-  path
 }
 
 #' Find an executable
@@ -80,15 +83,38 @@ path_derive_precommit_exec <- function() {
 #'   directory may also not exist.
 #' @keywords internal
 path_derive_precommit_exec_impl <- function(candidate) {
-  assumed <- fs::path(candidate, precommit_executable_file())
-  existant <- assumed[fs::file_exists(assumed)]
-  if (length(existant) > 0) {
-    existant[1]
+  existant <- path_candidate_to_actual(candidate)
+  if (length(existant) >= 1) {
+    existant
   } else {
     ""
   }
 }
 
+path_warn_multiple_execs <- function(paths) {
+  rlang::warn(paste0(
+    "We detected multiple pre-commit executables. This is likely ",
+    "going to get you into trouble in the future, e.g. when you want to ",
+    "upgrade, as you easily loose track of different versions. We strongly ",
+    "suggest to only keep one pre-commit executable and uninstall (or delete) ",
+    "the other ones. Here are the locations where we detected executables:\n\n",
+    "- ", paste0(paths, collapse = "\n- "), "\n\n",
+    "Note that in all local repos where you used pre-commit, the executable ",
+    "path is hardcoded (in .git/hooks/pre-commit). Deleting a referenced ",
+    "executable will break pre-commit for that local repo. A simple ",
+    "re-initialization with `precommit::use_precommit()` or ",
+    "`$ pre-commit install` will fix this for pre-commit hooks.\n\nIf you ",
+    "have hook types other than pre-commit such as pre-push (you can check ",
+    "which files are in .git/hooks/), you need to name the type and use the ",
+    "command line, i.e. `$ pre-commit install -t pre-push`. "
+  ))
+}
+
+path_candidate_to_actual <- function(candidate) {
+  assumed <- fs::path(candidate, precommit_executable_file())
+  assumed[file_exists(assumed)]
+}
+
 path_derive_precommit_exec_linux <- function() {
   path_derive_precommit_exec_impl(
     path_if_exist(fs::path_home(".local/bin")) # 18.04 and 16.04 with pip3.
@@ -116,14 +142,15 @@ path_derive_precommit_exec_win_python3plus_base <- function() {
 
 # Only reason to capsule this: mock test.
 path_derive_precommit_exec_win_python3plus_candidates <- function() {
-  fs::dir_ls(path_if_exist(fs::path_home("AppData/Roaming/Python/"), regexp = "Python[0-9]+$"))
+  fs::dir_ls(path_if_exist(fs::path_home("AppData/Roaming/Python/")), regexp = "Python[0-9]+$")
 }
 
 
 path_derive_precommit_exec_macOS <- function() {
   c(
     fs::path(sort(fs::dir_ls(path_if_exist("~/Library/Python/")), decreasing = TRUE), "bin"), # pip
-    "/usr/local/bin" # homebrew
+    "/usr/local/bin", # homebrew
+    "/opt/homebrew/bin" # homebrew Apple Silicon (M1 chip)
   ) %>%
     path_derive_precommit_exec_impl()
 }
@@ -134,7 +161,7 @@ path_derive_precommit_exec_macOS <- function() {
 #' Returns `""` if no executable is found.
 #' @keywords internal
 path_derive_precommit_exec_path <- function() {
-  unname(Sys.which(precommit_executable_file())[1])
+  unname(Sys.which(precommit_executable_file()))
 }
 
 #' Derive the path to the conda pre-commit executable
@@ -156,7 +183,7 @@ path_derive_precommit_exec_conda <- function() {
         "space on disk, you probably want to delete the pre-commit executable at ",
         path, " and the package sources in the ",
         "conda environment r-reticulate with ",
-        "`reticulate::conda_remove('r-reticulate', 'precommit')`."
+        "`reticulate::conda_remove('r-reticulate', 'pre-commit')`."
       ))
     }
   }
@@ -167,14 +194,13 @@ path_derive_precommit_exec_conda_impl <- function(conda_env) {
   tryCatch(
     {
       ls <- reticulate::conda_list()
-
       path_reticulate <- fs::path_dir(ls[ls$name == conda_env, "python"][1])
       derived <- fs::path(
         path_reticulate,
         ifelse(is_windows(), "Scripts", ""),
         precommit_executable_file()
       )
-      unname(ifelse(fs::file_exists(derived), derived, ""))
+      unname(ifelse(file_exists(derived), derived, ""))
     },
     error = function(e) ""
   )
